pype32.directories.NetMetaDataStreamEntry

Package pype32 :: Module directories :: Class NetMetaDataStreamEntry |
[hide private]
[frames] | no frames]

# Class NetMetaDataStreamEntry

source code

                     object --+
                              |
    baseclasses.BaseStructClass --+
                                  |
                                 NetMetaDataStreamEntry

NetMetaDataStreamEntry object.

Instance Methods | [hide private]
__init__(self, shouldPack=True) x.__init__(...) initializes x; see help(type(x)) for signature | source code
getType(self) Returns consts.NET_METADATA_STREAM_ENTRY. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Inherited from baseclasses.BaseStructClass
__len__(self) | source code
__str__(self) str(x) | source code
dict |
getFields(self) Returns all the class attributues. | source code
sizeof(self) | source code

Static Methods | [hide private]
NetMetaDataStreamEntry |
parse(readDataInstance) Returns a new NetMetaDataStreamEntry object. | source code

Instance Variables | [hide private]
| offset DWORD offset.
| size DWORD size.
| name AlignedString name.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Parameters: `shouldPack` - (Optional) If the value is set to `True`, the class will be packed. If the value is set to `False`, the class will not be packed. Overrides: object.__init__ (inherited documentation)

### getType(self) | source code
Returns consts.NET_METADATA_STREAM_ENTRY. Raises: `NotImplementedError` - The method wasn't implemented in the inherited class. Overrides: baseclasses.BaseStructClass.getType

### parse(readDataInstance) Static Method | source code
Returns a new NetMetaDataStreamEntry object. Parameters: `readDataInstance` (ReadData) - A ReadData object with data to be parsed as a NetMetaDataStreamEntry. Returns: NetMetaDataStreamEntry A new NetMetaDataStreamEntry object.